==> pluxml_5.3.orig.tar.gz: PluXml-5.3/core/lang/pt/update.php <==
<?php

$LANG = array(

'L_SAVE_SUCCESSFUL'					=> 'Gabação dos dados efectuado com sucesso',
'L_UPDATE_TITLE'					=> 'Actualização de PluXml',
'L_WRONG_PHP_VERSION'				=> 'PluXml exige a execução de PHP 5 ou superior para poder funcionar.',

'L_SELECT_LANG'						=> 'Seléccione o seu idioma',
'L_INPUT_CHANGE'					=> 'Alterar',

'L_UPDATE_UPTODATE'					=> 'Pluxml está actualizado.',
'L_UPDATE_NOT_AVAILABLE'			=> 'Nenhuma actualização disponivél.',
'L_UPDATE_BACK'						=> 'Voltar ao web-site',
'L_UPDATE_WARNING1'					=> 'Está prestes a actualizar a sua versão de Pluxml',
'L_UPDATE_SELECT_VERSION'			=> 'Seléccione na lista seguinte a sua antiga versão de Pluxml a actualizar.',
'L_UPDATE_WARNING2'					=> 'Se a sua antiga versão não se encontra na lista seguinte, e porque não existe processo de actualização automático, porque a sua versão é muito antiga.<br />Sugerimos que descarregue a nova versão  de <a href="http://www.pluxml.org">PluXml</a> e que faça uma nova instalção.',
'L_UPDATE_WARNING3'					=> 'Atenção, antes de comoçar a actualização não se esquêça de fazer uma cópia dos seus dados, que se encontram na pasta "data"',
'L_UPDATE_START'					=> 'Come¸ar a actualização',

'L_UPDATE_ENDED'					=> 'Actualização terminada.',
'L_UPDATE_INPROGRESS'				=> 'Aplicação das actualizações',
'L_UPDATE_ERROR'					=> 'Um erro ocorreu durante o processo de actualização.',
'L_UPDATE_SUCCESSFUL'				=> 'Todas a actualizaçõés foram aplicadas com sucesso !',

'L_UPDATE_UPDATE_PARAMETERS_FILE'	=> 'Actualização do ficheiro... parametres.xml',
'L_UPDATE_CREATE_TAGS_FILE'			=> 'Criação do ficheiro... tags.xml',
'L_UPDATE_ERR_CREATE_TAGS_FILE'		=> 'Ocorreu um erro durante o processo de criação do ficheiro tags.xml',
'L_UPDATE_CREATE_THEME_FILE'		=> 'Criação do ficheiro tema (template)',
'L_UPDATE_ERR_CREATE_THEME_FILE'	=> 'Ocorreu um erro durante o processoa de criação do ficheiro',
'L_UPDATE_ARTICLES_CONVERSION'		=> 'Conversão dos artigos ao novo formato',
'L_UPDATE_ERR_FILE_PROCESSING'		=> 'Ocorreu um erro durante o processo de tratamento do ficheiro',
'L_UPDATE_STATICS_MIGRATION'		=> 'Migração do ficheiro das páginas státicas',
'L_UPDATE_ERR_STATICS_MIGRATION'	=> 'Occoreu um erro durante o processo de migração do ficheiro das páginas státicas',
'L_UPDATE_CREATE_USERS_FILE'		=> 'Criação do ficheiro dos utilizadores',
'L_UPDATE_ERR_CREATE_USERS_FILE'	=> 'Ocorreu um erro durante o processo de creção do ficheiro dos utilizadores',
'L_UPDATE_USERS_MIGRATION'			=> 'Migração do ficheiro dos utilizadores',
'L_UPDATE_ERR_USERS_MIGRATION'		=> 'Ocorreu um erro durante o processo de migrção do ficheiro dos utilizadores',
'L_UPDATE_ERR_NO_USERS'				=> 'Nenhum utilizador presente no ficheiro',
'L_UPDATE_CREATE_HTACCESS_FILE'		=> 'Criação do ficheiro .htaccess',
'L_UPDATE_ERR_CREATE_HTACCESS_FILE'	=> 'Ocorreu um erro durante o processo de criação do ficheiro .htaccess',
'L_UPDATE_UPDATE_HTACCESS_FILE'		=> 'Atualizar o arquivo .htaccess',
'L_UPDATE_ERR_UPDATE_HTACCESS_FILE'	=> 'Erro ao atualizar o arquivo .htaccess',
'L_UPDATE_CATEGORIES_MIGRATION'		=> 'Migração do ficheiro das categorias',
'L_UPDATE_ERR_CATEGORIES_MIGRATION'	=> 'Ocorreu um erro durante o processo de migração do ficheiro das categorias',
'L_UPDATE_CREATE_PLUGINS_FILE'		=> 'Criação do ficheiro... plugins.xml',
'L_UPDATE_ERR_CREATE_PLUGINS_FILE'	=> 'Ocorreu um erro durante o processo de criação do ficheiro... plugins.xml',
'L_UPDATE_DELETE_FULLSCREEN_FILE'	=> 'Supressão do ficheiro... core/admin/fullscreen.php',
'L_UPDATE_ERR_DELETE_FULLSCREEN_FILE'=> 'Ocorreur um erro durante o processo de supressão do ficheiro... core/admin/fullscreen.php',
'L_UPDATE_DELETE_PLXTOOLBAR_FOLDER'	=>	'Supressão da pasta... core/plxtoolbar/',
'L_UPDATE_ERR_DELETE_PLXTOOLBAR_FOLDER' => 'Ocorreur um erro durante o processo de supressão da pasta...  core/plxtoolbar/',
'L_UPDATE_FILE'						=> 'Atualize arquivo',
'L_UPDATE_ERR_FILE'					=> 'Erro durante o ficheiro de actualização',
'L_UPDATE_PLUG_MOVEPARAMFILE'		=> 'Migrando arquivos parâmetros no arquivo de configuração do plugin',
'L_UPDATE_UPDATE_PLUGINS_FILE'		=> 'Actualização do ficheiro... plugins.xml',

);
?>

==> pluxml_5.5.orig.tar.gz: PluXml-5.5/core/lang/pt/update.php <==
<?php

$LANG = array(

'L_SAVE_SUCCESSFUL'					=> 'Gabação dos dados efectuado com sucesso',
'L_UPDATE_TITLE'					=> 'Actualização de PluXml',
'L_WRONG_PHP_VERSION'				=> 'PluXml exige a execução de PHP 5 ou superior para poder funcionar.',

'L_SELECT_LANG'						=> 'Seléccione o seu idioma',
'L_INPUT_CHANGE'					=> 'Alterar',

'L_UPDATE_UPTODATE'					=> 'Pluxml está actualizado.',
'L_UPDATE_NOT_AVAILABLE'			=> 'Nenhuma actualização disponivél.',
'L_UPDATE_BACK'						=> 'Voltar ao web-site',
'L_UPDATE_WARNING1'					=> 'Está prestes a actualizar a sua versão de Pluxml',
'L_UPDATE_SELECT_VERSION'			=> 'Seléccione na lista seguinte a sua antiga versão de Pluxml a actualizar.',
'L_UPDATE_WARNING2'					=> 'Se a sua antiga versão não se encontra na lista seguinte, e porque não existe processo de actualização automático, porque a sua versão é muito antiga.<br />Sugerimos que descarregue a nova versão  de <a href="http://www.pluxml.org">PluXml</a> e que faça uma nova instalção.',
'L_UPDATE_WARNING3'					=> 'Atenção, antes de comoçar a actualização não se esquêça de fazer uma cópia dos seus dados, que se encontram na pasta "data"',
'L_UPDATE_START'					=> 'Come¸ar a actualização',

'L_UPDATE_ENDED'					=> 'Actualização terminada.',
'L_UPDATE_INPROGRESS'				=> 'Aplicação das actualizações',
'L_UPDATE_ERROR'					=> 'Um erro ocorreu durante o processo de actualização.',
'L_UPDATE_SUCCESSFUL'				=> 'Todas a actualizaçõés foram aplicadas com sucesso !',

'L_UPDATE_UPDATE_PARAMETERS_FILE'	=> 'Actualização do ficheiro... parametres.xml',
'L_UPDATE_CREATE_TAGS_FILE'			=> 'Criação do ficheiro... tags.xml',
'L_UPDATE_ERR_CREATE_TAGS_FILE'		=> 'Ocorreu um erro durante o processo de criação do ficheiro tags.xml',
'L_UPDATE_CREATE_THEME_FILE'		=> 'Criação do ficheiro tema (template)',
'L_UPDATE_ERR_CREATE_THEME_FILE'	=> 'Ocorreu um erro durante o processoa de criação do ficheiro',
'L_UPDATE_ARTICLES_CONVERSION'		=> 'Conversão dos artigos ao novo formato',
'L_UPDATE_ERR_FILE_PROCESSING'		=> 'Ocorreu um erro durante o processo de tratamento do ficheiro',
'L_UPDATE_STATICS_MIGRATION'		=> 'Migração do ficheiro das páginas státicas',
'L_UPDATE_ERR_STATICS_MIGRATION'	=> 'Occoreu um erro durante o processo de migração do ficheiro das páginas státicas',
'L_UPDATE_CREATE_USERS_FILE'		=> 'Criação do ficheiro dos utilizadores',
'L_UPDATE_ERR_CREATE_USERS_FILE'	=> 'Ocorreu um erro durante o processo de creção do ficheiro dos utilizadores',
'L_UPDATE_USERS_MIGRATION'			=> 'Migração do ficheiro dos utilizadores',
'L_UPDATE_ERR_USERS_MIGRATION'		=> 'Ocorreu um erro durante o processo de migrção do ficheiro dos utilizadores',
'L_UPDATE_ERR_NO_USERS'				=> 'Nenhum utilizador presente no ficheiro',
'L_UPDATE_CREATE_HTACCESS_FILE'		=> 'Criação do ficheiro .htaccess',
'L_UPDATE_ERR_CREATE_HTACCESS_FILE'	=> 'Ocorreu um erro durante o processo de criação do ficheiro .htaccess',
'L_UPDATE_UPDATE_HTACCESS_FILE'		=> 'Atualizar o arquivo .htaccess',
'L_UPDATE_ERR_UPDATE_HTACCESS_FILE'	=> 'Erro ao atualizar o arquivo .htaccess',
'L_UPDATE_CATEGORIES_MIGRATION'		=> 'Migração do ficheiro das categorias',
'L_UPDATE_ERR_CATEGORIES_MIGRATION'	=> 'Ocorreu um erro durante o processo de migração do ficheiro das categorias',
'L_UPDATE_CREATE_PLUGINS_FILE'		=> 'Criação do ficheiro... plugins.xml',
'L_UPDATE_ERR_CREATE_PLUGINS_FILE'	=> 'Ocorreu um erro durante o processo de criação do ficheiro... plugins.xml',
'L_UPDATE_DELETE_FULLSCREEN_FILE'	=> 'Supressão do ficheiro... core/admin/fullscreen.php',
'L_UPDATE_ERR_DELETE_FULLSCREEN_FILE'=> 'Ocorreur um erro durante o processo de supressão do ficheiro... core/admin/fullscreen.php',
'L_UPDATE_DELETE_PLXTOOLBAR_FOLDER'	=>	'Supressão da pasta... core/plxtoolbar/',
'L_UPDATE_ERR_DELETE_PLXTOOLBAR_FOLDER' => 'Ocorreur um erro durante o processo de supressão da pasta...  core/plxtoolbar/',
'L_UPDATE_FILE'						=> 'Atualize arquivo',
'L_UPDATE_ERR_FILE'					=> 'Erro durante o ficheiro de actualização',
'L_UPDATE_PLUG_MOVEPARAMFILE'		=> 'Migrando arquivos parâmetros no arquivo de configuração do plugin',
'L_UPDATE_UPDATE_PLUGINS_FILE'		=> 'Actualização do ficheiro... plugins.xml',
'L_UPDATE_COMMENTS_MIGRATION'		=> 'Comentários de migração',
'L_UPDATE_ERR_COMMENTS_MIGRATION'	=> 'Erro durante a migração comentários',
);
?>
